| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeigootsvqpk6th5xpdtzanxum3earifrrezfyhylfrit7yvqdrtgpe` | A protocol for ABCI requests and responses.                                                                                |
| connection/valory/abci/0.1.0                                  | `bafybeihtcupik5qk27qnvbc5ep2oqgrka2y7e5pqzxp3v2bidpbxxachyq` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeighbvg6if7bwswosgajlzgz36pwuyttu3vyfqgwi3xayvdxtl53lq` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeidahlnxcjaylwetojmmkhxeb7d7jtmiqxzfae2g7zwyluxvlvhsr4` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeigklynwl3mfav5yt5zdkrqe6rukv4ygdhpdusk66ojt4jj7tunxcy` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeielrs5qih3r6qhnily6x4h4j4j6kux6eqr546homow4c5ljgfyljq` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeihcilb27ekgoplmc43iog2zrus63fufql4rly2umbuj573nu3zpg4` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeid4ufdirr3qaksk72iwnuzfelhzqwh7t3q56x2ixhzvwltte4yy5a` | Service Manager contract                                                                                                   |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeickvk3l5b5ryzu3amva73nbcccajeygnjitd3lzgb7kb4z754a3oa` | IPFS e2e testing application.                                                                                              |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeidgyqzkngpo4tdvyrj4apq5txscrslptrp5n5r4xt5uchu4f3edfa` | Agent for testing the ABCI connection.                                                                                     |
| contract/valory/service_registry/0.1.0                        | `bafybeihnlcu4tnnfrict3z7kclcba7hnniqomamnsoio3bjytshzrxovsm` | Service Registry contract                                                                                                  |
| protocol/valory/tendermint/0.1.0                              | `bafybeidjqmwvgi4rqgp65tbkhmi45fwn2odr5ecezw6q47hwitsgyw4jpa` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeibjzhsengtxfofqpxy6syamplevp35obemwfp4c5lhag3v2bvgysa` | A protocol specification for IPFS requests and responses.                                                                  |
| skill/valory/abstract_abci/0.1.0                              | `bafybeicvw6rteuzd2kfj6u4rwsrqbwipfwwhzafttviii3twzqzjokcl2i` | The abci skill provides a template of an ABCI application.                                                                 |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeiazhdqb3upmvuthxpxmaplczezyr37rqktcvjgsywehot3ux4zvre` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeifnqddpl3rui4gzh7x75feptzlxwzvix72kbqo5t5yvof2r62jzke` | abstract round-based ABCI application                                                                                      |
| contract/valory/multisend/0.1.0                               | `bafybeieg4tywd5lww2vygvpkilg3hcepa4rmhehjuamyvdf6vazt554v6u` | MultiSend contract                                                                                                         |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeiexo675m25pcu2dcp6dwqilpymn46xm4ne2v4d5xsavdu3vantssy` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeif6iqhzjx3tzxzsgubje4yeaien7ydqo3pcjm5zdbk6b7fhmdbnmu` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeibtp5ugd45v5lgh7zdziqo4vlciedbywcclenjhlzk2dyohmte7bu` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeifkjdoj7i6hacv44to62ohbdbnsilcue2c4ghzwhbegbahxjsq3kq` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeiby765punrqo7pciugm4gastlsivkxuj7acluodkeukjmd3zuplkq` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeianskoghhdffn4wqquup3rtziefq6jareutugb6a5zkbvuvctgk3i` | A client for the ABCI counter application.                                                                                 |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeigvearu2pcf7oepxpfj64lbzgm2oxcbgxarxxbqkgd44dvarmij74` | Hello World ABCI application.                                                                                              |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeialmzikymc4jbgvey3uilweue4kdrjt7lbyz6w6rksjhkmg2yxuwm` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeidzv7ota52ykxiftciceqb7ygbu3j5acgbq4g6bzqk3gp4aylyg6q` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeibxmlhwquvmmgswyy42elv6pyawskrtr3qj4zy22kz2vm3ziysu6y` | ABCI application for testing the ABCI connection.                                                                          |
| agent/valory/abstract_abci/0.1.0                              | `bafybeib7liikswpxlcv5tri7w4gaj2jt5usefblcotzldupd35ia2tglo4` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeiggz75ctm7kjqz7nwr4n74nnea3i623maheoshsjxqtotsqt6ff4y` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeihwqpwbejtk25xvlsltinpxe5myb33vpv4ee7qxqgsbwuzkdzujoe` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/hello_world/0.1.0                                | `bafybeifulc2gc4fqeyimb5hihvx3bjrbr437xdbb52rfjz4sgp67zajtfq` | Hello World ABCI example.                                                                                                  |
| agent/valory/register_reset/0.1.0                             | `bafybeibnuxwbb4xyluz5u2pse73zur477x2dquvveogw47qsnylyyvfqni` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeialzsm6d6v5p4nwwy4tdls5smat4mbmykomyr2z6kjemjfi3nv6ke` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeicz73cmpcijyjefzwo4gdfwsigjg7ui2au4drrb56oe2gnq3qyws4` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeifsqrqusfacaennm2uhtuokwlshsf7ptrqrltd54jrtpon2u6b25y` | Agent for testing the ABCI connection.                                                                                     |
| service/valory/counter/0.1.0                                  | `bafybeiavvykikddaozj5vunp2drtlaausbix3yh4hv7tpkzityqpzjvilu` | A set of agents incrementing a counter                                                                                     |
| service/valory/hello_world/0.1.0                              | `bafybeia3r5ulvcgux6cfdk6atja75h4r6nzazqs4v4xewuhohhvxg5gzla` | A simple demonstration of a simple ABCI application                                                                        |
| service/valory/register_reset/0.1.0                           | `bafybeifiw4zt7cukh5izqy7ybc6i2rmjngu3ciivmfecnk4inisic7coxe` | Test and debug tendermint reset mechanism.                                                                                 |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeihnbudh6zqhrsobhxstrmjvrvbuvfwjlbfc65ofec6ptzwbyhrtpq` | ABCI application for dummy skill that registers and resets                                                                 |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeihvxr6g3vpcjur233tuiy26s67kjc2jnk5tve3ezdwvwjux4fqvlq` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| contract/valory/multicall2/0.1.0                              | `bafybeihhn3vic2yje7ehmi43a4wus4vnei5nwihetwk73tqtgbnn44pr2u` | The MakerDAO multicall2 contract.                                                                                          |
| skill/valory/slashing_abci/0.1.0                              | `bafybeidkwuyzjof4srz2gd6irl3wklxi6ebepsvid6pdtdbz5bdkioagla` | Slashing skill.                                                                                                            |
| skill/valory/offend_abci/0.1.0                                | `bafybeih74czok5wly6db4635ssdzjcxixlprra5fhdcee7qxg7wl6532om` | Offend ABCI application.                                                                                                   |
| skill/valory/offend_slash_abci/0.1.0                          | `bafybeiaappqga6tz2y7x7ezyr2cvd7nawhlnboqwwjtlqwjda3lty2iedm` | ABCI application used in order to test the slashing abci                                                                   |
| agent/valory/offend_slash/0.1.0                               | `bafybeigda3ji42ovsocw2ua4x2rwv2qmeyeis4qxuun7yddfb76tluesca` | Offend and slash to test the slashing feature.                                                                             |
| contract/valory/erc20/0.1.0                                   | `bafybeiag7wpfri44bwrx26374mnxyglmwxod6gu37foqkvloqr7oeldlgu` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| contract/valory/service_registry_token_utility/0.1.0          | `bafybeifdia2y5546tvk6xzxeaqzf2n5n7dutj2hdzbgenxohaqhjtnjqm4` | The scaffold contract scaffolds a contract to be implemented by the developer.                                             |
| protocol/open_aea/signing/1.0.0                               | `bafybeifuxs7gdg2okbn7uofymenjlmnih2wxwkym44lsgwmklgwuckxm2m` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeiapa5ilsobggnspoqhspftwolrx52udrwmaxdxgrk26heuvl4oooa` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeia5bxdua2i6chw6pg47bvoljzcpuqxzy4rdrorbdmcbnwmnfdobtu` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeigsvceac33asd6ecbqev34meyyjwu3rangenv6xp5rkxyz4krvcby` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeiasywsvax45qmugus5kxogejj66c5taen27h4voriodz7rgushtqa` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeieoeuy4brzimtnubmokwirhrx27ezls6cdnl5qik4rkykfle3nn2y` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeigfoz7d7si7s4jehvloq2zmiiocpbxcaathl3bxkyarxoerxq7g3a` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeihdnfdth3qgltefgrem7xyi4b3ejzaz67xglm2hbma2rfvpl2annq` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
